# Bug Report
The bug i want to show you is related to the following library for android:
- com.github.barteksc:android-pdf-viewer:2.8.2

The **bug** is that:
- *loading pdf view in background doesn't show pdf (the view is blank)*

**Note**: i found this bug only in android 5.0 and 6.0. In android 8.0 the background loading is perfect. (I haven't tried with other android versions).

**Note**: the loading is perfect if it is not performed in background

------

## Introduction
To allow you a better debug i have created a simple project to show you the bug. The project is made of:

- **MainActivity** with 2 buttons:
  1. load pdf from assets folder
  2. load pdf from internal storage


- **PdfActivity**: in which the PDFView it will be loaded

- **PdfLoaderTask**: AsyncTask which performs the pdf loading in background

The tests are made with emulated devices with android 6.0 and android 8.0. In the following tests i load pdf file from assets folder and from internal storage.

![alt text](./mainactivity.png)

------

## 1. Test with Android 6.0
The device i have used is emulated (but i have also found this bug on my ASUS_Z00LD with android 5.0.2). It has the following features:


- Name: Nexus_6_API_23
- CPU/ABI: Google APIs Intel Atom (x86)
- Skin: 1440x2560
- hw.dPad: no
- hw.lcd.height: 2560
- runtime.network.speed: full
- hw.accelerometer: yes
- hw.device.name: Nexus 6
- vm.heapSize: 64
- skin.dynamic: yes
- hw.device.manufacturer: Google
- hw.lcd.width: 1440
- hw.gps: yes
- hw.initialOrientation: Portrait
- skin.path.backup: _no_skin
- image.androidVersion.api: 23
- hw.audioInput: yes
- image.sysdir.1: system-images/android-23/google_apis/x86/
- tag.id: google_apis
- showDeviceFrame: no
- hw.camera.back: webcam0
- hw.mainKeys: no
- AvdId: Nexus_6_API_23
- hw.camera.front: webcam0
- hw.lcd.density: 560
- avd.ini.displayname: Nexus 6 API 23
- hw.gpu.mode: auto
- hw.device.hash2: MD5:984dbf66b1aaafcdb7e89573ffb74b46
- hw.ramSize: 1536
- hw.trackBall: no
- PlayStore.enabled: false
- hw.battery: yes
- hw.sdCard: yes
- tag.display: Google APIs
- runtime.network.latency: none
- hw.keyboard: no
- hw.sensors.proximity: yes
- disk.dataPartition.size: 800M
- hw.sensors.orientation: yes
- avd.ini.encoding: UTF-8
- hw.gpu.enabled: yes

------


### 1.1. Loading From Assets Folder

- **Background Loading**: the logcat is the following:

![alt text](./logcat_android6_from_assets.png)



- **Main Thread Loading**: the logcat is the following:

![alt text](./logcat_android6_from_assets_main_thread.png)

------

### 1.2. Loading From Internal Storage

- **Background Loading**: the logcat is the following:

![alt text](./logcat_android6_from_internal_storage.png)


- **Main Thread Loading**: the logcat is the following:

![alt text](./logcat_android6_from_assets_main_thread.png)

------

### 1.3. Results

- **Background Loading**:

![alt text](./android6.png)

- **Main Thread Loading**

![alt text](./android6_loaded.png)



------

## 2. Test with Android 8.0
The device i have used is emulated. It has the following features:

- Name: One_plus_3T_API_26
- CPU/ABI: Google APIs Intel Atom (x86)
- Target: google_apis [Google APIs] (API level 26)
- Skin: 1080x1920
- SD Card: 100M
- hw.dPad: no
- hw.lcd.height: 1920
- runtime.network.speed: full
- hw.accelerometer: yes
- hw.device.name: One plus 3T
- vm.heapSize: 256
- skin.dynamic: yes
- hw.device.manufacturer: User
- hw.lcd.width: 1080
- hw.gps: yes
- hw.initialOrientation: Portrait
- skin.path.backup: _no_skin
- image.androidVersion.api: 26
- hw.audioInput: yes
- image.sysdir.1: system-images/android-26/google_apis/x86/
- tag.id: google_apis
- showDeviceFrame: no
- hw.camera.back: emulated
- hw.mainKeys: no
- AvdId: One_plus_3T_API_26
- hw.camera.front: emulated
- hw.lcd.density: 480
- avd.ini.displayname: One plus 3T API 26
- hw.gpu.mode: auto
- hw.device.hash2: MD5:1c925b9117dd9f33c5128dac289a0d68
- hw.ramSize: 1536
- hw.trackBall: no
- PlayStore.enabled: false
- fastboot.forceColdBoot: no
- hw.battery: yes
- hw.cpu.ncore: 4
- hw.sdCard: yes
- tag.display: Google APIs
- runtime.network.latency: none
- hw.keyboard: yes
- hw.sensors.proximity: yes
- disk.dataPartition.size: 800M
- hw.sensors.orientation: yes
- avd.ini.encoding: UTF-8
- hw.gpu.enabled: yes


------


### 2.1. Loading From Assets Folder

- **Background Loading**: the logcat is the following:

![alt text](./logcat_android8_from_assets.png)



- **Main Thread Loading**: the logcat is the following:

![alt text](./logcat_android8_from_assets_main_thread.png)

------

### 2.2. Loading From Internal Storage

- **Background Loading**: the logcat is the following:

![alt text](./logcat_android8_from_internal_storage.png)


- **Main Thread Loading**: the logcat is the following:

![alt text](./logcat_android8_from_internal_storage_main_thread.png)

------

### 2.3. Results

- **Background** & **Main Thread Loading**:

![alt text](./android8.png)


------
### Conclusions
As you can see in the logcats, when the loading is performed in background, the "FPDF library" is not initialized, so the PDF is not showed. Infact, there isn't the following log:
- *D/jniPdfium: Init FPDF library*

I hope this can be useful to solve the bug. Thank you for this wonderful library!

------
## Developer Infos
- **Project Name**: loadpdfinbackgroundexample
- **Author**: LT Dev
- **Email**: develtar@gmail.com
- **Library Version**: com.github.barteksc:android-pdf-viewer:2.8.2
