package it.ltdev.loadpdfinbackgroundexample;

import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.content.pm.PackageManager;
import android.content.res.AssetManager;
import android.support.design.widget.FloatingActionButton;
import android.support.v4.app.ActivityCompat;
import android.support.v4.content.ContextCompat;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.widget.Button;

import com.github.barteksc.pdfviewer.PDFView;

import java.io.File;
import java.io.FileOutputStream;
import java.io.InputStream;
import java.io.OutputStream;


public class MainActivity extends AppCompatActivity {
    private static final String TAG = MainActivity.class.getSimpleName();

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        final Context mContext = this;
        final String pdfName = "loremipsum.pdf";

        // Load PDF view from assets folder
        Button btnLoadFromAsset = findViewById(R.id.btn_load_from_asset);
        btnLoadFromAsset.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                Intent pdfActivityIntent = new Intent(mContext, PdfActivity.class);
                pdfActivityIntent.putExtra(AppUtils.PATH, pdfName);
                pdfActivityIntent.putExtra(AppUtils.LOAD_FROM_ASSET, true);
                startActivity(pdfActivityIntent);
            }
        });

        // Load PDF view from storage
        Button btnLoadFromInternalStorage = findViewById(R.id.btn_load_from_internal_storage);
        btnLoadFromInternalStorage.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                // Create folder
                String folderPath = getFilesDir()+ File.separator+ "loadPdfTest/pdfs/";
                File folder = new File(folderPath);
                if (!folder.exists()) {
                    folder.mkdirs();
                }

                // Copy pdf file from asset to internal storage
                String path = folderPath+pdfName;
                copyFileFromAsset(mContext, path, pdfName);
                Log.i(TAG, "PDF Path = "+path);

                Intent pdfActivityIntent = new Intent(mContext, PdfActivity.class);
                pdfActivityIntent.putExtra(AppUtils.PATH, path);
                pdfActivityIntent.putExtra(AppUtils.LOAD_FROM_ASSET, false);
                startActivity(pdfActivityIntent);
            }
        });
    }




    private void copyFileFromAsset(Context ctx, String path, String assetPath){
        File file = new File(path);
        if (!file.exists()){
            AssetManager assetManager = ctx.getAssets();
            try {
                InputStream in = assetManager.open(assetPath);
                OutputStream out = new FileOutputStream(path);
                byte[] buffer = new byte[1024];
                int read = in.read(buffer);
                while (read != -1) {
                    out.write(buffer, 0, read);
                    read = in.read(buffer);
                }
            } catch (Exception e) {
                e.getMessage();
            }
        }
    }

}
