package it.ltdev.loadpdfinbackgroundexample;

import android.Manifest;
import android.content.Context;
import android.content.Intent;
import android.os.Bundle;
import android.support.v7.app.AppCompatActivity;
import android.util.Log;
import android.view.View;
import android.widget.Toast;

import com.github.barteksc.pdfviewer.PDFView;

import java.io.File;

/**
 * Created by ltdev on 31/03/18.
 */
public class PdfActivity extends AppCompatActivity {
    private static final String TAG = PdfActivity.class.getSimpleName();
    private Context mContext;
    private PDFView mPdfView;
    private String path;
    boolean loadFromAsset;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_pdf);
        mContext = this;

        // Get activity intent params
        Intent i = getIntent();
        path = i.getStringExtra(AppUtils.PATH);
        loadFromAsset = i.getBooleanExtra(AppUtils.LOAD_FROM_ASSET, true);

        mPdfView = findViewById(R.id.pdfView);

        // Load PDF
        loadPdf(false);

    }




    private void loadPdf(boolean loadInBackground) {
        if (loadInBackground) {
            // Load PDF in background
            PdfLoaderTask pdfLoaderTask = new PdfLoaderTask();
            pdfLoaderTask.setParams(path, loadFromAsset, mPdfView);
            pdfLoaderTask.execute();
        } else {
            // Load PDF in main thread
            PDFView.Configurator conf = null;
            if (loadFromAsset) {
                Log.i(TAG, "Loading from assets: " + path);
                conf = mPdfView.fromAsset(path);
            } else {
                Log.i(TAG, "Loading from storage: " + path);
                final File pdfFile = new File(path);
                Log.i(TAG, "PDF file exists = " + String.valueOf(pdfFile.exists()));
                if (pdfFile.exists()) {
                    conf = mPdfView.fromFile(pdfFile);
                }
            }

            conf.enableSwipe(true)
                    .enableDoubletap(true)
                    .swipeHorizontal(false)
                    .defaultPage(1)
                    .enableAnnotationRendering(false)
                    .password(null)
                    .load();
        }
    }

}
